@@ -9,7 +9,7 @@ from requests import Response
 from waiting import wait as wait_lib
 
 from api_manager.constants import Entities, HttpActions, APIState
-from api_manager.exeptions import NotConfiguredException
+from api_manager.exceptions import NotConfiguredException
 from api_manager.methods import get
 
 ASYNC_COMMAND_IGNORE_CODES = [HTTPStatus.UNAUTHORIZED, HTTPStatus.FORBIDDEN, HTTPStatus.INTERNAL_SERVER_ERROR]
